import { writeFile } from 'node:fs/promises';
import { mkdir } from 'node:fs/promises';
import { join } from 'node:path';
import { stripVTControlCharacters, styleText } from 'node:util';
import { pager } from '../cli/pager.js';
import { promptToInputDisplayMode } from '../cli/prompt.js';
import { getTempDir } from '../util/file-system.js';
import { unreachable } from '../util/type-check.js';
export async function doPrintResultDetailsAction(core, results, selectedRuleIds) {
    const displayMode = await promptToInputDisplayMode();
    const formattedResultDetails = await core.formatResultDetails(results, selectedRuleIds);
    if (displayMode === 'printInTerminal') {
        console.log(formattedResultDetails);
    }
    else if (displayMode === 'printInTerminalWithPager') {
        await pager(formattedResultDetails);
    }
    else if (displayMode === 'writeToFile') {
        const tempDir = getTempDir();
        const filePath = join(tempDir, 'lint-result-details.txt');
        await mkdir(tempDir, { recursive: true }); // Create the directory because it might not exist
        await writeFile(filePath, stripVTControlCharacters(formattedResultDetails), 'utf8');
        console.log(styleText('cyan', `Wrote to ${filePath}`));
    }
    else {
        // eslint-disable-next-line @typescript-eslint/restrict-template-expressions
        unreachable(`Unknown display mode: ${displayMode}`);
    }
}
//# sourceMappingURL=print-result-details.js.map