import type { ESLint } from 'eslint';
import type { ParsedCLIOptions } from './cli/parse-argv.js';
type LegacyESLintOptions = {
    type: 'eslintrc';
} & Pick<ESLint.LegacyOptions, 'useEslintrc' | 'overrideConfigFile' | 'extensions' | 'rulePaths' | 'ignorePath' | 'cache' | 'cacheLocation' | 'overrideConfig' | 'cwd' | 'resolvePluginsRelativeTo' | 'plugins'>;
type FlatESLintOptions = {
    type: 'flat';
} & Pick<ESLint.Options, 'overrideConfigFile' | 'cache' | 'cacheLocation' | 'overrideConfig' | 'cwd' | 'flags'>;
export type ESLintOptions = LegacyESLintOptions | FlatESLintOptions;
/** The config of eslint-interactive */
export type Config = {
    patterns: string[];
    formatterName?: string | undefined;
    quiet?: boolean | undefined;
    cwd?: string | undefined;
    eslintOptions: ESLintOptions;
    flags?: string[] | undefined;
};
type ESLintOptionsType = 'eslintrc' | 'flat';
export declare function translateCLIOptions(options: ParsedCLIOptions, eslintOptionsType: ESLintOptionsType): Config;
/** Default config of `Core` */
export declare const configDefaults: {
    formatterName: string;
    quiet: false;
    cwd: string;
    eslintOptions: {
        useEslintrc: true;
        overrideConfigFile: undefined;
        extensions: undefined;
        rulePaths: undefined;
        ignorePath: undefined;
        cache: false;
        cacheLocation: undefined;
        overrideConfig: undefined;
        resolvePluginsRelativeTo: undefined;
    };
};
export type NormalizedConfig = {
    patterns: string[];
    formatterName: string;
    quiet: boolean;
    cwd: string;
    eslintOptions: ESLintOptions;
};
export declare function normalizeConfig(config: Config): NormalizedConfig;
export {};
//# sourceMappingURL=config.d.ts.map